package org.fortiss.tooling.kernel.ui.service;

import org.fortiss.tooling.kernel.ToolingKernelActivator;
import org.fortiss.tooling.kernel.model.constraints.IConstraint;
import org.fortiss.tooling.kernel.model.constraints.IConstraintVerificationStatus;
import org.fortiss.tooling.kernel.service.IConstraintVerificationService;
import org.fortiss.tooling.kernel.utils.ServicesUtils;

/**
 * GUI aspects of {@link IConstraintVerificationService}.
 * 
 * @author aravantinos
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 8090ADCE9F13AA09D85DC04367654660
 */
public interface IConstraintVerificationUIService {
	/**
	 * Returns the service instance.
	 * 
	 * @deprecated use {@link ServicesUtils#getService(org.osgi.framework.Bundle, Class)} and
	 *             {@link ServicesUtils#ungetService(org.osgi.framework.Bundle, Class)}, instead.
	 *             See also {@link ToolingKernelActivator#getService(Class)} and
	 *             {@link ToolingKernelActivator#ungetService(Class)}
	 */
	@Deprecated
	public static IConstraintVerificationUIService getInstance() {
		return getService(IConstraintVerificationUIService.class);
	}

	/** Action to take when trying to open the given status. */
	public void openStatus(IConstraintVerificationStatus status);

	/** True if the given status can be open. */
	public boolean canOpen(IConstraintVerificationStatus status);

	/** Install the given constraint: install notifiers and triggers an "onOutdate" event. */
	public void install(IConstraint constraint);

	/**
	 * The following features deal with the usage of constraints to drive the process.
	 * 
	 * EXPERIMENTAL.
	 */

	/** Activates the constraint type. */
	public <T extends IConstraint> void activate(Class<T> constraintEltClass);

	/** Deactivates the constraint type. */
	public <T extends IConstraint> void deactivate(Class<T> constraintEltClass);
}
